@@ -297,11 +297,37 @@ def visu(
     return fmdt.args.Args(visu_args=visu_args, detect_args=None)
 
 def check(
-    trk_path: str, gt_path: str
-    ) -> fmdt.res.CheckingResult:
+    trk_path: str, gt_path: str, stdout: str = None, log = False
+    ) -> fmdt.res.CheckResult:
+    """Call fmdt-check
+    
+    Parameters
+    ----------
+    std_out (str): File to store stdout of fmdt-check"""
 
     argv = ["fmdt-check", "--trk-path", trk_path, "--gt-path", gt_path]
-    subprocess.run(argv)
+    res = subprocess.run(argv, stdout=subprocess.PIPE)
+
+    file_content = res.stdout.decode()
+
+    if not stdout is None:
+        with open(stdout, "w") as file:
+            file.write(file_content)
+
+        stats = fmdt.res.load_check_stats(stdout)
+        gt_table = fmdt.res.load_check_gt_table(stdout)
+    
+    else:
+
+        stats = None
+        gt_table = None
+
+    if (log):
+        print(file_content)
+
+    return fmdt.res.CheckResult(gt_table=gt_table, stats=stats)
+
+
 
 def detect_directory(dir_name: str, args: fmdt.args.Args, log=False):
     """Call `fmdt-detect` on all videos in the directory `dir_name` using the settings stored in `args`
