@@ -234,7 +234,11 @@ class Video:
         #================== Additional Parameters ====================
         trk_out_path: str | None = "trk.txt",
         log: bool = False,
-        timeout: float = None):
+        timeout: float = None,
+        #================== Check ====================================
+        stdout: str = None,
+        log_check = False
+        ):
 
         args = fmdt.args.detect_args(self.full_path(), vid_in_start, vid_in_stop, 
         vid_in_skip, vid_in_buff, vid_in_loop, vid_in_threads, light_min, light_max, 
@@ -244,7 +248,7 @@ class Video:
 
         res = args.detect()
 
-        self.evaluate_args(args, res.trk_list)
+        self.evaluate_args(args, res.trk_list, stdout, log=log_check)
 
 
 
@@ -279,7 +283,15 @@ class Video:
         """Check whether the video path in self.full_path() exists on disk"""
         return os.path.exists(self.full_path())
 
-    def evaluate_args(self, args: fmdt.Args, meteors: list[fmdt.truth.HumanDetection], rerun: bool = False, tmp_gt_file = "tmp_meteors.txt"):
+    def evaluate_args(
+            self,
+            args: fmdt.Args,
+            meteors: list[fmdt.truth.HumanDetection],
+            rerun: bool = False,
+            tmp_gt_file = "tmp_meteors.txt",
+            stdout: str = None,
+            log = False
+        ):
         """Call fmdt-detect and fmdt-check to evaluate how well a given set of arguments detects our ground truth
         
         Parameters
@@ -308,7 +320,7 @@ class Video:
 
         # Then call fmdt_check
 
-        fmdt.check(args.detect_args.trk_out_path, tmp_gt_file)
+        return fmdt.check(args.detect_args.trk_out_path, tmp_gt_file, stdout, log)
 
 
     @staticmethod
